==> maven-profile-2.0-sources.jar: org/apache/maven/profiles/Repository.java <==
/*
 * $Id$
 */

package org.apache.maven.profiles;

  //---------------------------------/
 //- Imported classes and packages -/
//---------------------------------/

import java.util.*;

/**
 * Class Repository.
 * 
 * @version $Revision$ $Date$
 */
public class Repository extends RepositoryBase 
implements java.io.Serializable
{


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field releases
     */
    private RepositoryPolicy releases;

    /**
     * Field snapshots
     */
    private RepositoryPolicy snapshots;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Method getReleases
     */
    public RepositoryPolicy getReleases()
    {
        return this.releases;
    } //-- RepositoryPolicy getReleases() 

    /**
     * Method getSnapshots
     */
    public RepositoryPolicy getSnapshots()
    {
        return this.snapshots;
    } //-- RepositoryPolicy getSnapshots() 

    /**
     * Method setReleases
     * 
     * @param releases
     */
    public void setReleases(RepositoryPolicy releases)
    {
        this.releases = releases;
    } //-- void setReleases(RepositoryPolicy) 

    /**
     * Method setSnapshots
     * 
     * @param snapshots
     */
    public void setSnapshots(RepositoryPolicy snapshots)
    {
        this.snapshots = snapshots;
    } //-- void setSnapshots(RepositoryPolicy) 


            public boolean equals( Object obj )
            {
                return super.equals( obj );
            }
          }

==> maven-profile-2.0.7-sources.jar: org/apache/maven/profiles/Repository.java <==
/*
 * $Id$
 */

package org.apache.maven.profiles;

/**
 * 
 *         Repository contains the information needed for
 * establishing connections with remote repoistory
 *       
 * 
 * @version $Revision$ $Date$
 */
public class Repository extends RepositoryBase 
implements java.io.Serializable
{


      //--------------------------/
     //- Class/Member Variables -/
    //--------------------------/

    /**
     * Field releases
     */
    private RepositoryPolicy releases;

    /**
     * Field snapshots
     */
    private RepositoryPolicy snapshots;


      //-----------/
     //- Methods -/
    //-----------/

    /**
     * Get How to handle downloading of releases from this repositor
     */
    public RepositoryPolicy getReleases()
    {
        return this.releases;
    } //-- RepositoryPolicy getReleases() 

    /**
     * Get How to handle downloading of snapshots from this
     * repository
     */
    public RepositoryPolicy getSnapshots()
    {
        return this.snapshots;
    } //-- RepositoryPolicy getSnapshots() 

    /**
     * Set How to handle downloading of releases from this
     * repository
     * 
     * @param releases
     */
    public void setReleases(RepositoryPolicy releases)
    {
        this.releases = releases;
    } //-- void setReleases(RepositoryPolicy) 

    /**
     * Set How to handle downloading of snapshots from this
     * repository
     * 
     * @param snapshots
     */
    public void setSnapshots(RepositoryPolicy snapshots)
    {
        this.snapshots = snapshots;
    } //-- void setSnapshots(RepositoryPolicy) 


            public boolean equals( Object obj )
            {
                return super.equals( obj );
            }
          
    private String modelEncoding = "UTF-8";

    public void setModelEncoding( String modelEncoding )
    {
        this.modelEncoding = modelEncoding;
    }

    public String getModelEncoding()
    {
        return modelEncoding;
    }}
